 /*
 * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  */
/*
 * $Id: CallbackStatusIF.java 65615 2012-03-29 19:02:39Z sdimilla $
 */

package com.sun.ts.tests.jpa.core.callback.common;

import java.util.List;

public interface CallbackStatusIF {
    String getTestName();
    void setTestName(String s);
    String getEntityName();
    
    boolean isPrePersistCalled();
    List getPrePersistCalls();
    void setPrePersistCalled(boolean b);
    void addPrePersistCall(String shortName);
    
    boolean isPostPersistCalled();
    List getPostPersistCalls();
    void setPostPersistCalled(boolean b);
    void addPostPersistCall(String shortName);
    
    boolean isPreRemoveCalled();
    List getPreRemoveCalls();
    void setPreRemoveCalled(boolean b);
    void addPreRemoveCall(String shortName);
    
    boolean isPostRemoveCalled();
    List getPostRemoveCalls();
    void setPostRemoveCalled(boolean b);
    void addPostRemoveCall(String shortName);
    
    boolean isPreUpdateCalled();
    List getPreUpdateCalls();
    void setPreUpdateCalled(boolean b);
    void addPreUpdateCall(String shortName);
    
    boolean isPostUpdateCalled();
    List getPostUpdateCalls();
    void setPostUpdateCalled(boolean b);
    void addPostUpdateCall(String shortName);
    
    boolean isPostLoadCalled();
    List getPostLoadCalls();
    void setPostLoadCalled(boolean b);
    void addPostLoadCall(String shortName);
}
